pub struct ListActiveValidatorsResponse {
pub validators: Vec<ValidatorInfo>,
}Fields
validators: Vec<ValidatorInfo>Trait Implementations
Sourceimpl Clone for ListActiveValidatorsResponse
impl Clone for ListActiveValidatorsResponse
Sourcefn clone(&self) -> ListActiveValidatorsResponse
fn clone(&self) -> ListActiveValidatorsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListActiveValidatorsResponse
impl Debug for ListActiveValidatorsResponse
Sourceimpl<'de> Deserialize<'de> for ListActiveValidatorsResponse
impl<'de> Deserialize<'de> for ListActiveValidatorsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListActiveValidatorsResponse
impl JsonSchema for ListActiveValidatorsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListActiveValidatorsResponse
impl PartialEq for ListActiveValidatorsResponse
Sourcefn eq(&self, other: &ListActiveValidatorsResponse) -> bool
fn eq(&self, other: &ListActiveValidatorsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ListActiveValidatorsResponse
impl StructuralPartialEq for ListActiveValidatorsResponse