pub struct ListValidatorSlashingResponse {
pub addr: String,
pub start_height: u64,
pub slashing: Vec<ValidatorSlashing>,
pub tombstoned: bool,
pub jailed_until: Option<Expiration>,
}Fields
addr: StringOperator address
start_height: u64Block height of first validator addition to validators set
slashing: Vec<ValidatorSlashing>Slashing events, if any
tombstoned: boolWhether or not a validator has been tombstoned (killed out of validator set)
jailed_until: Option<Expiration>If validator is jailed, it will show expiration time