pub struct UnvalidatedDistributionContract {
pub contract: String,
pub ratio: Decimal,
}Fields
contract: StringThe unvalidated address of the contract to which part of the reward tokens is sent to.
ratio: DecimalThe ratio of total reward tokens for an epoch to be sent to that contract for further distribution.